Learn R Programming

neonSoilFlux (version 3.0.0)

flux_fingerprint_plot: Helper function to plot QF results for fluxes.

Description

Given a flux measurement data frame, show when the flux and diffusivity measurements produced a QF value

Usage

flux_fingerprint_plot(input_fluxes, input_diffus_method = "Marshall")

Value

A ggplot graph where we have ordered factors showing the QA values a given flux computation

Arguments

input_fluxes

data frame of computed fluxes

input_diffus_method

character string of diffusivity method used to compute fluxes. Can be one of "Marshall" or "Millington-Quirk".

Author

John Zobitz zobitz@augsburg.edu

Examples

Run this code
# Make a fingerprint plot for computed flux values:
flux_fingerprint_plot(sjer_flux_2022_06)

Run the code above in your browser using DataLab