reprocess_vswc: Internal helper function to reprocess SWC data from...

View source: R/reprocess_vswc.R

reprocess_vswcR Documentation

Internal helper function to reprocess SWC data from calibration data

Description

Apply correct calibration data functions for SWC data - see https://data.neonscience.org/data-products/DP1.00094.001

Usage

reprocess_vswc(site_name, download_date, token = NULL)

Arguments

site_name

Required. NEON code for a particular site (a string)

download_date

Required. Date where we end getting NEON data. Format: YYYY-MM (can't specify day). So "2020-05" means it will grab data for the entire 5th month of 2020. (a string). Downloads data for a given month only

token

NEON API token. Required to download data. The function [neon_api_token()] will install it locally to your R environment. A token can be acquired at https://www.neonscience.org/resources/learning-hub/tutorials/api-token-setup.

Value

A data frame of startDateTime, horizontalPosition, and the associated QF flag.

A list containing stacked swc data

Author(s)

John Zobitz zobitz@augsburg.edu,

Examples

## Not run: 
# Test to see if you have a NEON API token installed in your local environment.
# If you don't have one, an error message will report a website for access.
get_neon_api_token()

# If no token exists, then see documentation for neonSoilFlux::neon_api_token()

out_swc <- reprocess_vswc("SJER","2022-06")

## End(Not run)

neonSoilFlux documentation built on July 3, 2026, 5:07 p.m.