sjer_flux_2022_06: Computed flux values at a NEON site

sjer_flux_2022_06R Documentation

Computed flux values at a NEON site

Description

A nested dataset containing computed fluxes at the SJER site from June 2022. Fluxes were computed with using compute_neon_flux(sjer_env_data_2022_06,sjer_megapit_data_2022_06).

Usage

data(sjer_flux_2022_06)

Format

A nested data frame item list with 7200 rows and 8 columns

Details

  • startDateTime: Time period of measurement (as POSIXct)

  • horizontalPosition: Sensor location where flux is computed

  • flux_compute: A nested tibble with variables: flux, flux_err, gradient, gradient_err, method (one of 4 implemented), and r2 of the linear fit for method 000

  • surface_diffusivity: Computation of surface diffusivity. A nexted tibble with variables: zOffset, diffusivity, diffusivityExpUncert, diffus_method

  • soilCO2concentrationMeanQF: QF flag for soil CO2 concentration across all vertical depths at the given horizontal position: 0 = no issues, 1 = monthly mean used in measurement, 2 = QF fail

  • VSWCMeanQF: QF flag for soil water content across all vertical depths at the given horizontal position: 0 = no issues, 1 = monthly mean used in measurement, 2 = QF fail

  • soilTempMeanQF: QF flag for soil temperature across all vertical depths at the given horizontal position: 0 = no issues, 1 = monthly mean used in measurement, 2 = QF fail

  • staPresMeanQF: QF flag for atmospheric pressure across all vertical depths at the given horizontal position: 0 = no issues, 1 = monthly mean used in measurement, 2 = QF fail


neonSoilFlux documentation built on July 3, 2026, 5:07 p.m.