swc_correct: Internal function to correct depths for VSWC NEON data.

View source: R/swc_correct.R

swc_correctR Documentation

Internal function to correct depths for VSWC NEON data.

Description

Given the expanded SWC data, return a corrected version based on the values below

Usage

swc_correct(input_swc, curr_site, reference_time)

Arguments

input_swc

Required. input soil water content data from acquire_neon_data (as a list)

curr_site

Current site we are working with

reference_time

Current month we are working with

Value

A revised list of corrected soil water content and depths.

Author(s)

John Zobitz zobitz@augsburg.edu

Examples

## Not run: 
# Test to see if you have a NEON API token installed in your local environment.
# If you don't have one, an error message will report a website for access.
neon_token <- get_neon_api_token()

# If no token exists, then see documentation for neonSoilFlux::neon_api_token()

# Download the soil water content data:
site_swc <- neonUtilities::loadByProduct(
dpID="DP1.00094.001",
site="SJER",
startdate="2020-05",
enddate="2020-05",
timeIndex = "30",
package="expanded",
check.size = FALSE,
include.provisional = TRUE,
token = neon_token
)

# Then correct the swc:
site_swc <- swc_correct(site_swc,"SJER","2020-05")

## End(Not run)

neonSoilFlux documentation built on July 3, 2026, 5:07 p.m.