powered by
Given a flux measurement data frame, show when the flux and diffusivity measurements produced a QF value
flux_fingerprint_plot(input_fluxes, input_diffus_method = "Marshall")
A ggplot graph where we have ordered factors showing the QA values a given flux computation
data frame of computed fluxes
character string of diffusivity method used to compute fluxes. Can be one of "Marshall" or "Millington-Quirk".
John Zobitz zobitz@augsburg.edu
# Make a fingerprint plot for computed flux values: flux_fingerprint_plot(sjer_flux_2022_06)
Run the code above in your browser using DataLab